<?php

namespace Newage\Votes\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Newage\Votes\Http\Requests\VoteVoterRequest;
use Newage\Votes\Interfaces\VoteVoterRepositoryInterface;
use Newage\Votes\Models\VoteVoter;

/**
 * Resource controller class for vote_voter.
 */
class VoteVoterResourceController extends BaseController
{

    /**
     * Initialize vote_voter resource controller.
     *
     * @param type VoteVoterRepositoryInterface $vote_voter
     *
     * @return null
     */
    public function __construct(VoteVoterRepositoryInterface $vote_voter)
    {
        parent::__construct();
        $this->repository = $vote_voter;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Newage\Votes\Repositories\Criteria\VoteVoterResourceCriteria::class);
    }

    /**
     * Display a list of vote_voter.
     *
     * @return Response
     */
    public function index(VoteVoterRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Newage\Votes\Repositories\Presenter\VoteVoterPresenter::class)
                ->$function();
        }

        $vote_voters = $this->repository->paginate();

        return $this->response->title(trans('votes::vote_voter.names'))
            ->view('votes::vote_voter.index', true)
            ->data(compact('vote_voters'))
            ->output();
    }

    /**
     * Display vote_voter.
     *
     * @param Request $request
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function show(VoteVoterRequest $request, VoteVoter $vote_voter)
    {

        if ($vote_voter->exists) {
            $view = 'votes::vote_voter.show';
        } else {
            $view = 'votes::vote_voter.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('votes::vote_voter.name'))
            ->data(compact('vote_voter'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new vote_voter.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VoteVoterRequest $request)
    {

        $vote_voter = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('votes::vote_voter.name')) 
            ->view('votes::vote_voter.create', true) 
            ->data(compact('vote_voter'))
            ->output();
    }

    /**
     * Create new vote_voter.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VoteVoterRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $vote_voter                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('votes::vote_voter.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('votes/vote_voter/' . $vote_voter->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/votes/vote_voter'))
                ->redirect();
        }

    }

    /**
     * Show vote_voter for editing.
     *
     * @param Request $request
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function edit(VoteVoterRequest $request, VoteVoter $vote_voter)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('votes::vote_voter.name'))
            ->view('votes::vote_voter.edit', true)
            ->data(compact('vote_voter'))
            ->output();
    }

    /**
     * Update the vote_voter.
     *
     * @param Request $request
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function update(VoteVoterRequest $request, VoteVoter $vote_voter)
    {
        try {
            $attributes = $request->all();

            $vote_voter->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('votes::vote_voter.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('votes/vote_voter/' . $vote_voter->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('votes/vote_voter/' . $vote_voter->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the vote_voter.
     *
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function destroy(VoteVoterRequest $request, VoteVoter $vote_voter)
    {
        try {

            $vote_voter->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('votes::vote_voter.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('votes/vote_voter/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('votes/vote_voter/' . $vote_voter->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple vote_voter.
     *
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function delete(VoteVoterRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('votes::vote_voter.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('votes/vote_voter'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/votes/vote_voter'))
                ->redirect();
        }

    }

    /**
     * Restore deleted vote_voters.
     *
     * @param Model   $vote_voter
     *
     * @return Response
     */
    public function restore(VoteVoterRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('votes::vote_voter.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/votes/vote_voter'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/votes/vote_voter/'))
                ->redirect();
        }

    }

}
