<?php

namespace Newage\Votes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Votes\Models\VoteItem;

class VoteItemPolicy
{

    /**
     * Determine if the given user can view the vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function view(UserPolicy $user, VoteItem $vote_item)
    {
        if ($user->canDo('votes.vote_item.view') && $user->isAdmin()) {
            return true;
        }

        return $vote_item->user_id == user_id() && $vote_item->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('votes.vote_item.create');
    }

    /**
     * Determine if the given user can update the given vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function update(UserPolicy $user, VoteItem $vote_item)
    {
        if ($user->canDo('votes.vote_item.edit') && $user->isAdmin()) {
            return true;
        }

        return $vote_item->user_id == user_id() && $vote_item->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VoteItem $vote_item)
    {
        return $vote_item->user_id == user_id() && $vote_item->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VoteItem $vote_item)
    {
        if ($user->canDo('votes.vote_item.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vote_item.
     *
     * @param UserPolicy $user
     * @param VoteItem $vote_item
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VoteItem $vote_item)
    {
        if ($user->canDo('votes.vote_item.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
