<?php

namespace Newage\Votes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Votes\Models\VoteTopic;

class VoteTopicPolicy
{

    /**
     * Determine if the given user can view the vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function view(UserPolicy $user, VoteTopic $vote_topic)
    {
        if ($user->canDo('votes.vote_topic.view') && $user->isAdmin()) {
            return true;
        }

        return $vote_topic->user_id == user_id() && $vote_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('votes.vote_topic.create');
    }

    /**
     * Determine if the given user can update the given vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function update(UserPolicy $user, VoteTopic $vote_topic)
    {
        if ($user->canDo('votes.vote_topic.edit') && $user->isAdmin()) {
            return true;
        }

        return $vote_topic->user_id == user_id() && $vote_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VoteTopic $vote_topic)
    {
        return $vote_topic->user_id == user_id() && $vote_topic->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VoteTopic $vote_topic)
    {
        if ($user->canDo('votes.vote_topic.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vote_topic.
     *
     * @param UserPolicy $user
     * @param VoteTopic $vote_topic
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VoteTopic $vote_topic)
    {
        if ($user->canDo('votes.vote_topic.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
