<?php

namespace Newage\Votes\Policies;

use Litepie\User\Contracts\UserPolicy;
use Newage\Votes\Models\VoteVoter;

class VoteVoterPolicy
{

    /**
     * Determine if the given user can view the vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function view(UserPolicy $user, VoteVoter $vote_voter)
    {
        if ($user->canDo('votes.vote_voter.view') && $user->isAdmin()) {
            return true;
        }

        return $vote_voter->user_id == user_id() && $vote_voter->user_type == user_type();
    }

    /**
     * Determine if the given user can create a vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('votes.vote_voter.create');
    }

    /**
     * Determine if the given user can update the given vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function update(UserPolicy $user, VoteVoter $vote_voter)
    {
        if ($user->canDo('votes.vote_voter.edit') && $user->isAdmin()) {
            return true;
        }

        return $vote_voter->user_id == user_id() && $vote_voter->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, VoteVoter $vote_voter)
    {
        return $vote_voter->user_id == user_id() && $vote_voter->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function verify(UserPolicy $user, VoteVoter $vote_voter)
    {
        if ($user->canDo('votes.vote_voter.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given vote_voter.
     *
     * @param UserPolicy $user
     * @param VoteVoter $vote_voter
     *
     * @return bool
     */
    public function approve(UserPolicy $user, VoteVoter $vote_voter)
    {
        if ($user->canDo('votes.vote_voter.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
